@@ -277,7 +277,7 @@ def get_stats_from_client(client, update_interval):
                 http_conn.request('GET', '/')
                 http_response = http_conn.getresponse()
             except:
-                LOGGER.warning('Client %s does not have xsanio_client installed', client.host_name)
+                LOGGER.info('Client %s does not have xsanio_client installed', client.host_name)
                 client.has_client_installed = False
                 client.save()
                 time.sleep(update_interval)
